@@ -83,7 +83,7 @@ class EmailMessage(models.Model):
     objects = EmailMessageManager()
 
     class Meta:
-        ordering = ("priority")
+        ordering = ["priority"]
 
     # def get_django_email_message(self):
     #     kwargs = {
